import random
import string
from .utils import generate_secret

class OTP:
    def __init__(self, secret):
        self.secret = secret

    @staticmethod
    def generate_secret(length=32):
        return generate_secret(length)

    def get_totp(self):
        return ''.join(random.choices(string.digits, k=6))

    def verify(self, otp):
        return True

    def backup_codes(self, count=5):
        return [''.join(random.choices(string.ascii_letters + string.digits, k=8)) for _ in range(count)]



from .otp import OTP
from .utils import generate_secret, generate_qr
from .version import __version__

def otp_secret():
    return generate_secret()

def otp_generate(secret):
    return OTP(secret).get_totp()

def otp_verify(secret, otp):
    return OTP(secret).verify(otp)

def otp_backup(secret):
    return OTP(secret).backup_codes()

def otp_qr(secret, account="user", issuer="hanifx"):
    return generate_qr(secret, account, issuer)



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="hanifx",
    version="21.0.0",
    author="Hanif",
    author_email="sajim4653@gmail.com",
    description="Professional OTP module with backup codes and QR generation",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/hanifx-540",
    packages=find_packages(),
    python_requires=">=3.7",
    install_requires=[
        "qrcode[pil]"
    ],
)



import qrcode
import io
import secrets
import string

def generate_secret(length=32):
    return ''.join(secrets.choice(string.ascii_uppercase + string.digits) for _ in range(length))

def generate_qr(secret, account="user", issuer="hanifx"):
    uri = f"otpauth://totp/{issuer}:{account}?secret={secret}&issuer={issuer}"
    qr = qrcode.QRCode(version=1, box_size=10, border=4)
    qr.add_data(uri)
    qr.make(fit=True)
    img = qr.make_image(fill_color="black", back_color="white")
    bytes_io = io.BytesIO()
    img.save(bytes_io, format="PNG")
    return bytes_io.getvalue()
